<?php
    /**
     * The public-facing functionality of the plugin.
     *
     * Defines the plugin name, version, and two examples hooks for how to
     * enqueue the public-facing stylesheet and JavaScript.
     *
     * @package    Trackboxx
     * @subpackage Trackboxx/public
     */
    class Trackboxx_Public {
        /**
         * The ID of this plugin.
         *
         * @since    1.0.0
         * @access   private
         * @var      string    $plugin_name    The ID of this plugin.
         */
        private $plugin_name;

        /**
         * The version of this plugin.
         *
         * @since    1.0.0
         * @access   private
         * @var      string    $version    The current version of this plugin.
         */
        private $version;

        /**
         * Initialize the class and set its properties.
         *
         * @since    1.0.0
         * @param      string    $plugin_name       The name of the plugin.
         * @param      string    $version    The version of this plugin.
         */
        public function __construct( $plugin_name, $version ) {
            $this->plugin_name = $plugin_name;
            $this->version = $version;
        }

        /**
         * Register the JavaScript for the public-facing side of the site.
         *
         * @since    1.0.0
         */
        public function enqueue_scripts() {
            $trackboxxId = get_option("trackboxx_tracking_id");
            ?>
            <?php if (isset($trackboxxId["input"]) && $trackboxxId["input"]) : ?>
                <script>
                    (
                        function (d, s, id, w, f) {
                            w[f] = w[f] || function () {
                                (
                                    w[f].q = w[f].q || []
                                ).push(arguments);
                            };
                            var js, fjs = d.getElementsByTagName(s)[0];
                            if (d.getElementById(id)) {
                                return;
                            }
                            js = d.createElement(s);
                            js.id = id;
                            js.onload = function () {
                                // remote script has loaded
                            };
                            js.async = true;
                            js.src = "https://cdn.trackboxx.info/p/tracker.js";
                            fjs.parentNode.insertBefore(js, fjs);
                        }(document, "script", "trackboxx-script", window, "trackboxx")
                    );
                    trackboxx("set", "siteId", "<?php echo $trackboxxId["input"] ?>");
                    trackboxx("trackPageview");
                </script>
            <?php endif; ?>
            <?php
        }
    }
